/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2023  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////


#include <QApplication>
#include <QFrame>
#include <QGridLayout>
#include <QGroupBox>
#include <QHBoxLayout>
#include <QPushButton>
#include <QRadioButton>
#include <QSpacerItem>
#include <QVBoxLayout>

#include "preferencesdialog.h"

TPreferencesDialog::TPreferencesDialog(
	const QWidget						*parent,
	const Qt::WindowFlags				flags)
:QDialog(const_cast<QWidget*>(parent),flags)
{
	QFrame								*separator_hline;
	QGridLayout							*dialog_layout;
	QGroupBox							*dmis_feature_type_group;
	QHBoxLayout							*button_hlayout;
	QPushButton							*close_button;
	QSpacerItem							*button_hspacer;
	QSpacerItem							*dialog_vspacer;
	QVBoxLayout							*verticalLayout;


	this->resize(400,210);

	dialog_layout = new QGridLayout(this);

	dmis_feature_type_group = new QGroupBox(this);

	verticalLayout = new QVBoxLayout(dmis_feature_type_group);

	d_meas_point_radio = new QRadioButton(dmis_feature_type_group);
	d_meas_point_radio->setChecked(true);
	verticalLayout->addWidget(d_meas_point_radio);

	d_const_point_radio = new QRadioButton(dmis_feature_type_group);
	verticalLayout->addWidget(d_const_point_radio);
	dialog_layout->addWidget(dmis_feature_type_group,0,0,1,1);

	dialog_vspacer = new QSpacerItem(0,0,QSizePolicy::Minimum,QSizePolicy::Expanding);
	dialog_layout->addItem(dialog_vspacer,1,0,1,1);

	separator_hline = new QFrame(this);
	separator_hline->setFrameShape(QFrame::HLine);
	separator_hline->setFrameShadow(QFrame::Sunken);
	dialog_layout->addWidget(separator_hline,2,0,1,1);

	button_hlayout = new QHBoxLayout();

	button_hspacer = new QSpacerItem(0,0,QSizePolicy::Expanding,QSizePolicy::Minimum);
	button_hlayout->addItem(button_hspacer);

	close_button = new QPushButton(this);
	close_button->setAutoDefault(false);
	button_hlayout->addWidget(close_button);
	dialog_layout->addLayout(button_hlayout,3,0,1,1);

	this->setWindowTitle(QStringLiteral("Preferences"));
	
	dmis_feature_type_group->setTitle(QStringLiteral("DMIS Output Feature Type"));
	d_meas_point_radio->setText(QStringLiteral("Measured Points"));
	d_const_point_radio->setText(QStringLiteral("Constructed Offset Points"));
	close_button->setText(QStringLiteral("Close"));
	
	connect(close_button,&QPushButton::clicked,this,&TPreferencesDialog::close);
}

TPreferencesDialog::~TPreferencesDialog(void)
{
}

TPreferencesDialog::TPreferences TPreferencesDialog::Preferences(void) const
{
	TPreferencesDialog::TPreferences	preferences;
	
	if(d_meas_point_radio->isChecked())
	{
		preferences.dmis_output_feature = TPreferencesDialog::MEASURED_POINT;
	}
	else
	{
		preferences.dmis_output_feature = TPreferencesDialog::OFFSET_POINT;
	}
	
	return preferences;
}

void TPreferencesDialog::Reset(
	const TPreferencesDialog::TPreferences &preferences)
{
	switch(preferences.dmis_output_feature)
	{
		case TPreferencesDialog::MEASURED_POINT:
//			d_const_point_radio->setChecked(false);
			d_meas_point_radio->setChecked(true);
			break;
			
		case TPreferencesDialog::OFFSET_POINT:
//			d_meas_point_radio->setChecked(false);
			d_const_point_radio->setChecked(true);
			break;
	}
}
