/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2023  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////


#ifndef VALIDATIONTODMISHEADERFILE
#define VALIDATIONTODMISHEADERFILE

#include <QMainWindow>
#include <vector>

#include "preferencesdialog.h"

#include "../../../core/vector3.h"

class QAction;
class QPlainTextEdit;
class QSettings;
class QCloseEvent;

class TValidation2DMIS : public QMainWindow
{
Q_OBJECT

public:

// CREATORS
	TValidation2DMIS(const QWidget *parent=0, Qt::WindowFlags flags=Qt::WindowFlags());
	~TValidation2DMIS(void);

// ACCESSORS

// MANIPULATORS

signals:

private slots:
	
	void Menu_Open(void);
	void Menu_Export_DMIS(void);
	void Menu_Preferences(void);
	
protected:
	virtual void closeEvent(QCloseEvent *event);

private:
	
enum TFeatureType
{
	FEATURE_UNKNOWN=0,
	FEATURE_PLANE,
	FEATURE_LINE,
	FEATURE_CIRCLE,
	FEATURE_SPHERE
};
	
struct TConstructionFeatures
{
	QString								feature_name;
	TVector3							position;
	TVector3							vector;
	double								diameter;
	std::vector<QString>				points;
};
	
	QAction								*d_action_export_dmis;
	QAction								*d_action_open;
	QAction								*d_action_quit;
	QAction								*d_action_preferences;
	QPlainTextEdit						*d_text_edit;
	TPreferencesDialog					*d_preferences_dialog;
	
	QSettings							*d_settings;
	QString								d_application_path;
	QString								d_data_path;
	QString								d_file_path;
	
	TPreferencesDialog::TPreferences	d_preferences;

	QString								d_dmis_text_buffer;
	bool								d_dmis_using_offset_points;
	
	std::vector<TConstructionFeatures>	d_construction_features;
	
	void Clear_Text(void);
	void Add_Text(const QString &text);
	void Update_Display(void);
	void Scroll_Text_Top(void);
	
	void Create_Header(void);
	void Process_Validation_File(const QByteArray &file_data);
	void Create_Footer(void);
	
	void Display_Program_Information(void);
	
	void Create_Constructed_Planes(void);
	void Create_Constructed_Lines(void);
	void Create_Constructed_Circles(void);
	void Create_Constructed_Spheres(void);

// NOT IMPLEMENTED
	TValidation2DMIS(const TValidation2DMIS&);
	TValidation2DMIS& operator=(const TValidation2DMIS&);
};

#endif
